#
# spec file for package NsCDE
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           NsCDE
Version:        2.3
Release:        1.4
Summary:        Not so Common Desktop Environment (NsCDE)
License:        GPL-3.0-only
URL:            https://github.com/NsCDE/NsCDE
Source0:        %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE leafpad.patch maurizio.galli@suse.com -- add leafpad to recognized texteditors
Patch0:         leafpad.patch
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  gettext-tools
BuildRequires:  ksh
BuildRequires:  make
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xpm)
BuildRequires:  pkgconfig(xproto)
Requires:       fvwm2
Recommends:     leafpad
Recommends:     pcmanfm
Recommends:     xscreensaver

%description
Visually, NsCDE mimics CDE, the well known Common Desktop Environment of
many commercial UNIX systems of the nineties. It supports CDE backdrops and
palettes with FVWM colorsets and has a theme generator for Xt, Xaw, Motif,
GTK2, GTK3, Qt4 and Qt5.

Integrating all these bits and pieces, the user gets a retro visual experience
across almost all X11 applications. Enriched with a bunch of powerful
FVWM concepts and functions, modern applications and font rendering,
NsCDE acts as a link between classic CDE look and a fast and
extensible environment, well suited for modern day computing.

%package doc
Summary:        Docs for %{name}
BuildArch:      noarch

%description doc
%{summary}.

%lang_package

%prep
%autosetup -p1

# Fix .desktop files
sed -i 's/OnlyShowIn=NsCDE;/OnlyShowIn=X-NsCDE;/g' ./xdg/applications/*.desktop

# Fix python shebangs
find . -name '*.in' -exec sed -i 's:#!@PYTHON@:#!/usr/bin/python3:g' {} +

%build
%configure
%make_build

%install
%make_install
%fdupes -s %{buildroot}
%find_lang %{name} --all-name

#fix upstream
chmod -x %{buildroot}%{_libdir}/%{name}/python/SpritesGtk2.py

%files
%license COPYING
%doc ChangeLog
%{_bindir}/nscde
%{_bindir}/nscde_fvwmclnt

%{_datadir}/icons/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/
%{_datadir}/xsessions/nscde.desktop
%dir %{_datadir}/desktop-directories
%{_datadir}/desktop-directories/*

%{_libexecdir}/%{name}

%{_libdir}/%{name}

%dir %{_sysconfdir}/xdg/menus
%config %{_sysconfdir}/xdg/menus/nscde-applications.menu

%files lang -f %{name}.lang

%files doc
%{_datadir}/doc/nscde

%changelog
* Wed Nov  6 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 2.3:
  * Font and Color Style Manager: reload new themes without FVWM restart
  * Qt6 integration support
  * Optional Picom X Compositor internal support
  * Thunderbird 102+ CSS theme integration support
  * Firefox up to 113+ CSS theme integration support
  * Font and Color Style Manager reshape, add integrations as separate dialog
  * (De)Iconify X11 freeze glitch fvwm workaround
  * Front Panel initial placement fix instead of workaround
  * Fix GWM FvwmScript segfault on exit
  * More missing icons in XDG icon theme
  * Handle gsettings org.gnome.desktop.interface color-scheme
  * Xscreensaver 6.X support
  * Add detailed X resources for xcalc and some old Athena based apps
  * Tuning X resources for more old apps
  * Font and Color Style Manager: remember widget integration options
  * GTK3 theme fixes: treat nasty header bar as toolbar
  * Initial setup: add detailed integration questions, Qt6 support
  * Front Panel clock: triangle hour and minute hands to match original
  * GWMPager as popup on workspace change in no-page mode
  * Fixed some easy-to-make keyboard shortcuts accidental calls
  * Firefox and Thunderbird user.js additions for nice initial look & feel
  * Thunderbird HTML compose window toolbar fix
  * Docs update, many portability fixes, misc fixes, some typo fixes
  * Portability and test phase fixes
- attach url to the source tarball
- use pkgconfig for devel packages
- fixed docs, so we can package it. (seperate package)
* Fri Feb 10 2023 Maurizio Galli <maurizio.galli@suse.com>
- Remove doc files because contain scripts etc that cause OBS to fail
- Fix duplicate filews causing OBS to fail
- Fix .desktop file to use X-NsCDE instead of NsCDE
- Fix Python scripts shebangs
* Thu Aug 11 2022 Lubos Kocman <lubos.kocman@suse.com>
- Add xscreensaver as NsCDE treats it as a default screensaver.
* Thu Aug 11 2022 Maurizio Galli <maurizio.galli@suse.com>
- Add leafpad.patch to ensure first time config wizard recognizes
  leafpad as text editor.
* Wed Aug 10 2022 Maurizio Galli <maurizio.galli@suse.com>
- Add a minimalistic text editor (leafpad) and a filemanager (pcmanfm)
  as soft dependencies. These are the bare minimum to have a usable system.
- Trimmed description in spec file
* Wed Aug 10 2022 Lubos Kocman <lubos.kocman@suse.com>
- Alignment with openSUSE packaging guidelines
  * Use %%find_lang
  had to use --all-name otherwise translations were not matched
  and package ended up with installed but unpackaged files
  * Get rid of empty post/postun sections
* Tue Aug  9 2022 Lubos Kocman <lubos.kocman@suse.com>
- Update to 2.2
  * Add kcalc colors tom match dtcalc (colormgr.local)
  * Fix rofi and dunst themes to work with new versions of programs
  * NsCDE .desktop files renamed to conform to standards
  * Front Panel on top of the screen possibility implemented. This
  can be achieved with "InfoStoreAdd frontpanel.on.top 1"
  in ~/.NsCDE/NsCDE.conf.
  * Icon theme updates
  * CSS: support firefox 100+
  * Consolidate GTK2 and GTK3 engine css files, add some fixes
  and match colors more correctly
  * Added Common User Access (CUA) key bindings. This is now
  default key binding set in NsCDE. Old key bindings scheme
  now called "nscde1x" can be used in ~/.NsCDE/NsCDE.conf
  with the "InfoStoreAdd kbd_bind_set nscde1x" - this can also
  be configured now with Keyboard Style Manager
  * Keyboard Style Manager addons, Mouse Style Manager fixes
  * Building: add --with-python-shebang="STRING" in configure
  to allow user to override strange alternatives managers on
  some systems
  * Reorganize f_PolkitAgent to be more portable and stable
  * Kvantum: Reshape in more Motif style Qt5 Combo Box
  * More Firefox CSS updates
  * Documentation updates for all of the above
